Struct Class_
Other items inxmas_elf::header
pub struct Class_(_);
impl Class_
pub fn as_class(self) -> Class
pub fn is_none(self) -> bool
impl Clone for Class_
fn clone(&self) -> Class_
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
source
impl Debug for Class_
fn fmt(&self, f: &mut Formatter<'_>) -> Result
Formats the value using the given formatter. Read more
impl PartialEq<Class_> for Class_
fn eq(&self, other: &Class_) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
self
other
==
fn ne(&self, other: &Class_) -> bool
This method tests for !=.
!=
impl Copy for Class_
impl Eq for Class_
impl StructuralEq for Class_
impl StructuralPartialEq for Class_
impl Send for Class_
impl Sync for Class_
impl Unpin for Class_
impl<T> Any for T where T: 'static + ?Sized,
pub fn type_id(&self) -> TypeId
Gets the TypeId of self. Read more
TypeId
impl<T> Borrow<T> for T where T: ?Sized,
pub fn borrow(&self) -> &T
Immutably borrows from an owned value. Read more
impl<T> BorrowMut<T> for T where T: ?Sized,
pub fn borrow_mut(&mut self) -> &mut T
Mutably borrows from an owned value. Read more
impl<T> From<T> for T
pub fn from(t: T) -> T
Performs the conversion.
impl<T, U> Into<U> for T where U: From<T>,
pub fn into(self) -> U
impl<T, U> TryFrom<U> for T where U: Into<T>,
type Error = Infallible
The type returned in the event of a conversion error.
pub fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto<U> for T where U: TryFrom<T>,
type Error = <U as TryFrom<T>>::Error
pub fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>