pub struct Flags(pub u32);
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
Formats the value using the given formatter. Read more
Formats the value using the given formatter.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Formats the value using the given formatter.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.